Improve this Doc View Source

The `$touchProvider` allows enabling / disabling ngTouch's ngClick directive.

## Methods

- ###

  `ngClickOverrideEnabled([enabled]);`

  Call this method to enable/disable ngTouch's ngClick directive. If enabled, the default ngClick directive will be replaced by a version that eliminates the 300ms delay for click events on browser for touch-devices.

  The default is `false`.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  enabled (optional) | boolean | update the ngClickOverrideEnabled state if provided, otherwise just return the current ngClickOverrideEnabled state

  #### Returns

  * | current value if used as getter or itself (chaining) if used as setter